@@ -67,7 +67,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
                         tls.append('CA1')
                     else:
                         for q, p in zip(range(2, 6), trls[2:][1::2]):
-                            if t * (q - 1) < i < t * q:
+                            if t * (q - 1) <= i < t * q:
                                 tls.append(p)
 
             df['time'], df['trial'] = time, tls
